use axum::extract::Query;
use axum::Json;
use axum_extra::extract::WithRejection;
use validator::Validate;
use domain::dto::feedback::FeedbackAdd;
use domain::dto::pageable::PageParams;
use domain::entities::feedback::Feedback;
use library::resp::pageable::Pageable;
use library::resp::rejection::IRejection;
use library::resp::response::{ResErr, ResOK, ResResult};

/// 添加反馈信息
pub async fn add_feedback(
    WithRejection(Json(req), _): IRejection<Json<FeedbackAdd>>
) -> ResResult<ResOK<()>> {
    if let Err(err) = req.validate() {
        return Err(ResErr::ErrParams(Some(err.to_string())));
    }

    service::feedback::add_feedback(req).await?;
    Ok(ResOK(None))
}

/// 获取反馈信息列表
pub async fn get_feedback_list_by_page(
    Query(page_params): Query<PageParams>
) -> ResResult<ResOK<Pageable<Feedback>>> {
    service::feedback::get_feedback_list_by_page(page_params.page, page_params.page_size).await
}