use chrono::NaiveDateTime;
use sqlx::PgPool;
use sqlx::types::chrono;

#[derive(Debug, Clone, Default)]
pub struct Player {
    pub id: i64,
    pub username: String,
    pub email: String,
    pub platform_id: String,
    pub user_type: String,
    pub country_code: String,
    pub created_at: NaiveDateTime,
    pub updated_at: NaiveDateTime,
}

impl Player {
    pub async fn find_by_platform_id(platform_id: &str, db_pool: &PgPool) -> Result<Player, sqlx::Error> {
        sqlx::query_as!(
            Player,
            r#"select * from player where platform_id = $1"#,
            platform_id
        )
            .fetch_one(db_pool)
            .await
    }

    pub async fn add_player_info(player_info: &mut Player, db_pool: &PgPool) -> Result<Player, sqlx::Error> {
        player_info.created_at = chrono::Local::now().naive_local();
        sqlx::query_as!(
            Player,
            r#"
            insert into player
            (username, email, platform_id, user_type, country_code, created_at)
            values
            ($1, $2, $3, $4, $5, $6) returning *"#,
            player_info.username,
            player_info.email,
            player_info.platform_id,
            player_info.user_type,
            player_info.country_code,
            player_info.created_at,
        ).fetch_one(db_pool).await
    }
}